# Wyzard
[![GitHub](https://img.shields.io/github/license/LyQuid12/Wyzard?label=Project%20License&logo=github)](https://github.com/LyQuid12/Wyzard/blob/main/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/wyzard?period=total&units=international_system&left_color=grey&right_color=blue&left_text=Downloads)](https://pypi.org/project/wyzard)
[![GitHub issues](https://img.shields.io/github/issues/LyQuid12/Wyzard?label=Issues&logo=github)](https://github.com/LyQuid12/Wyzard/issues)
[![GitHub Repo stars](https://img.shields.io/github/stars/LyQuid12/Wyzard?label=Github%20Stars&logo=github)](https://github.com/LyQuid12/Wyzard)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/wyzard?label=Python%20Version&logo=python&logoColor=yellow)](https://pypi.org/project/wyzard)
[![PyPI - Status](https://img.shields.io/pypi/status/wyzard?label=Package%20Status&logo=pypi&logoColor=yellow)](https://pypi.org/project/wyzard)

**Run various transformers models from one packages.**
These packages aim to run various machine learning models using the [transformers](https://github.com/huggingface/transformers/) from [Hugging Face](https://huggingface.co/). Made to be user-friendly, concise, easy-to-understand. 

By default, users don't need to choose a model anymore for various types of models, we have selected the one that fits the class. But the user can still replace it according to the model that the user wants.

> **Can run :**
- **Text-to-Image or Image generation** using [Diffusers package](https://github.com/huggingface/diffusers).
- **GPT/AI output detector** using [GPT2](https://huggingface.co/gpt2) model.
- **Object detection**
- **Image-to-Text or image captioning**

More? soon!


## Install
- Using pip :
```
pip install wyzard
```

## Example
Examples code for each class can be seen at [here](https://github.com/LyQuid12/Wyzard/tree/main/examples).

## Licence & Copyright

```
This Project under MIT License
Copyright (c) 2023-present LyQuid (LyQuid12)
```
